@@ -14,6 +14,7 @@ class FileLoader;
 }
 
 class QFileSystemWatcher;
+class QTimer;
 
 class Gallery : public MauiList
 {
@@ -73,7 +74,7 @@ public:
 private:
     FMH::FileLoader *m_fileLoader;
     QFileSystemWatcher *m_watcher;
-
+    QTimer *m_scanTimer;
     FMH::MODEL_LIST list = {};
 
     QList<QUrl> m_urls;
@@ -87,10 +88,7 @@ private:
     Status m_status = Status::Error;
     QString m_error;
 
-    QList<QUrl> extractTags(const QList<QUrl> &);
-
     void scan(const QList<QUrl> &, const bool & = true, const int & = PIX_QUERY_MAX_LIMIT);
-    void scanTags(const QList<QUrl> &, const int & = PIX_QUERY_MAX_LIMIT);
 
     void insert(const FMH::MODEL_LIST &);
 
@@ -134,5 +132,7 @@ public slots:
 
     int indexOfName(const QString &);
     void setActiveGeolocationTags(bool activeGeolocationTags);
+    void scanImagesText();
+
 };
 #endif // GALLERY_H
